#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ihaskell
version:              0.13.0.0
visibility:           public
id:                   ihaskell-0.13.0.0-2s2PQNLZS2w6ej9h7FKbJp
key:                  ihaskell-0.13.0.0-2s2PQNLZS2w6ej9h7FKbJp
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the Jupyter project.
description:
    IHaskell is a Haskell backend kernel for the Jupyter project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  a1cb461a29252f9d89f0e28fd9b0303d
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Evaluate.HTML IHaskell.Eval.Hoogle IHaskell.Eval.Info
    IHaskell.Eval.Inspect IHaskell.Eval.Lint IHaskell.Eval.ParseShell
    IHaskell.Eval.Parser IHaskell.Eval.Util IHaskell.Eval.Widgets
    IHaskell.Flags IHaskell.IPython IHaskell.IPython.Stdin
    IHaskell.Publish IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ihaskell-0.13.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ihaskell-0.13.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ihaskell-0.13.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.13.0.0-2s2PQNLZS2w6ej9h7FKbJp
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe binary-0.8.9.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-parser-0.2.8.0-318bldawSmiGvH3DCsmO2W
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-syntax-highlighter-0.0.10.0-EehFLTIUC018Rmdx5NlR6R
    haskeline-0.8.2.1 hlint-3.6.1-EmvofvV2u6ECYPCxkfChB1
    http-client-0.7.19-JFk9tUfcyF3FnWNRzLmEjW
    http-client-tls-0.3.6.4-Dj2m0zumhuN7HSttI52C5a
    ipython-kernel-0.12.1.0-79W37YH9KYfD213qn1UuFa parsec-3.1.16.1
    process-1.6.19.0 random-1.2.1.3-FxwYxgjgoojJKMc450MWAC
    shelly-1.12.0-3Vbtb4P6bc3IbO9aMR6FH4
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    strict-0.5.1-C0uxzVekFAZGL5fXpAslZX text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

